@@ -24,19 +24,7 @@
 #endif
 #include <Python.h>
 #include "sourcescanner.h"
-
-#ifdef G_OS_WIN32
-#define USE_WINDOWS
-#endif
-
-#ifdef _WIN32
-#include <fcntl.h>
-#include <io.h>
-#define WIN32_LEAN_AND_MEAN
-#define STRICT
-#include <windows.h>
-#endif
-
+#include <stdio.h>
 #include <glib-object.h>
 
 #ifndef Py_TYPE
@@ -53,10 +41,10 @@
 #endif
 
 /* forward declaration */
-MOD_INIT(_giscanner);
+_GI_EXTERN MOD_INIT(_giscanner);
 
 #define NEW_CLASS(ctype, name, cname, num_methods)	      \
-static const PyMethodDef _Py##cname##_methods[num_methods];    \
+static const PyMethodDef _Py##cname##_methods[num_methods] G_GNUC_UNUSED;    \
 PyTypeObject Py##cname##_Type = {             \
     PyVarObject_HEAD_INIT(NULL, 0)            \
     "scanner." name,                          \
@@ -451,83 +439,6 @@ pygi_source_scanner_parse_file (PyGISourceScanner *self,
   if (!PyArg_ParseTuple (args, "i:SourceScanner.parse_file", &fd))
     return NULL;
 
-#ifdef _WIN32
-  /* The file descriptor passed to us is from the C library Python
-   * uses. That is msvcr71.dll for Python 2.5 and msvcr90.dll for
-   * Python 2.6, 2.7, 3.2 etc; and msvcr100.dll for Python 3.3 and later.
-   * This code, at least if compiled with mingw, uses
-   * msvcrt.dll, so we cannot use the file descriptor directly. So
-   * perform appropriate magic.
-   */
-
-  /* If we are using the following combinations,
-   * we can use the file descriptors directly
-   * (Not if a build using WDK is used):
-   * Python 2.6.x/2.7.x with Visual C++ 2008
-   * Python 3.1.x/3.2.x with Visual C++ 2008
-   * Python 3.3+ with Visual C++ 2010
-   */
-
-#if (defined(_MSC_VER) && !defined(USE_WIN_DDK))
-#if (PY_MAJOR_VERSION==2 && PY_MINOR_VERSION>=6 && (_MSC_VER >= 1500 && _MSC_VER < 1600))
-#define MSVC_USE_FD_DIRECTLY 1
-#elif (PY_MAJOR_VERSION==3 && PY_MINOR_VERSION<=2 && (_MSC_VER >= 1500 && _MSC_VER < 1600))
-#define MSVC_USE_FD_DIRECTLY 1
-#elif (PY_MAJOR_VERSION==3 && PY_MINOR_VERSION>=3 && (_MSC_VER >= 1600 && _MSC_VER < 1700))
-#define MSVC_USE_FD_DIRECTLY 1
-#endif
-#endif
-
-#ifndef MSVC_USE_FD_DIRECTLY
-  {
-#if defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==2 && PY_MINOR_VERSION==5
-#define PYTHON_MSVCRXX_DLL "msvcr71.dll"
-#elif defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==2 && PY_MINOR_VERSION==6
-#define PYTHON_MSVCRXX_DLL "msvcr90.dll"
-#elif defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==2 && PY_MINOR_VERSION==7
-#define PYTHON_MSVCRXX_DLL "msvcr90.dll"
-#elif defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==2
-#define PYTHON_MSVCRXX_DLL "msvcr90.dll"
-#elif defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==3 && PY_MINOR_VERSION>=3
-#define PYTHON_MSVCRXX_DLL "msvcr100.dll"
-#else
-#error This Python version not handled
-#endif
-    HMODULE msvcrxx;
-    intptr_t (*p__get_osfhandle) (int);
-    HANDLE handle;
-
-    msvcrxx = GetModuleHandle (PYTHON_MSVCRXX_DLL);
-    if (!msvcrxx)
-    {
-      g_print ("No " PYTHON_MSVCRXX_DLL " loaded.\n");
-      return NULL;
-    }
-
-    p__get_osfhandle = (intptr_t (*) (int)) GetProcAddress (msvcrxx, "_get_osfhandle");
-    if (!p__get_osfhandle)
-    {
-      g_print ("No _get_osfhandle found in " PYTHON_MSVCRXX_DLL ".\n");
-      return NULL;
-    }
-
-    handle = (HANDLE) p__get_osfhandle (fd);
-    if (!p__get_osfhandle)
-    {
-      g_print ("Could not get OS handle from " PYTHON_MSVCRXX_DLL " fd.\n");
-      return NULL;
-    }
-
-    fd = _open_osfhandle ((intptr_t) handle, _O_RDONLY);
-    if (fd == -1)
-    {
-      g_print ("Could not open C fd from OS handle.\n");
-      return NULL;
-    }
-  }
-#endif
-#endif
-
   fp = fdopen (fd, "r");
   if (!fp)
     {
@@ -584,7 +495,7 @@ pygi_source_scanner_set_macro_scan (PyGISourceScanner *self,
 }
 
 static PyObject *
-pygi_source_scanner_get_symbols (PyGISourceScanner *self)
+pygi_source_scanner_get_symbols (PyGISourceScanner *self, G_GNUC_UNUSED PyObject *unused)
 {
   GSList *l, *symbols;
   PyObject *list;
@@ -605,7 +516,7 @@ pygi_source_scanner_get_symbols (PyGISourceScanner *self)
 }
 
 static PyObject *
-pygi_source_scanner_get_comments (PyGISourceScanner *self)
+pygi_source_scanner_get_comments (PyGISourceScanner *self, G_GNUC_UNUSED PyObject *unused)
 {
   GSList *l, *comments;
   PyObject *list;
@@ -624,6 +535,12 @@ pygi_source_scanner_get_comments (PyGISourceScanner *self)
       if (comment->comment)
         {
           comment_obj = PyUnicode_FromString (comment->comment);
+          if (!comment_obj)
+            {
+              g_print ("Comment is not valid Unicode in %s line %d\n", comment->filename, comment->line);
+              Py_INCREF (Py_None);
+              comment_obj = Py_None;
+            }
         }
       else
         {
@@ -664,171 +581,15 @@ static const PyMethodDef _PyGISourceScanner_methods[] = {
   { NULL, NULL, 0 }
 };
 
-
-static int calc_attrs_length(PyObject *attributes, int indent,
-			     int self_indent)
-{
-  int attr_length = 0;
-  int i;
-
-  if (indent == -1)
-    return -1;
-
-  for (i = 0; i < PyList_Size (attributes); ++i)
-    {
-      PyObject *tuple, *pyvalue;
-      PyObject *s = NULL;
-      char *attr, *value;
-      char *escaped;
-
-      tuple = PyList_GetItem (attributes, i);
-      if (PyTuple_GetItem(tuple, 1) == Py_None)
-	continue;
-
-      if (!PyArg_ParseTuple(tuple, "sO", &attr, &pyvalue))
-        return -1;
-
-      if (PyUnicode_Check(pyvalue)) {
-        s = PyUnicode_AsUTF8String(pyvalue);
-        if (!s) {
-          return -1;
-        }
-        value = PyBytes_AsString(s);
-      } else if (PyBytes_Check(pyvalue)) {
-        value = PyBytes_AsString(pyvalue);
-      } else {
-        PyErr_SetString(PyExc_TypeError,
-                        "value must be string or unicode");
-        return -1;
-      }
-
-      escaped = g_markup_escape_text (value, -1);
-      attr_length += 2 + strlen(attr) + strlen(escaped) + 2;
-      g_free(escaped);
-      Py_XDECREF(s);
-    }
-
-  return attr_length + indent + self_indent;
-}
-
-/* Hall of shame, wasted time debugging the code below
- * 20min - Johan 2009-02-19
- */
-static PyObject *
-pygi_collect_attributes (PyObject *self,
-			 PyObject *args)
-{
-  char *tag_name;
-  PyObject *attributes;
-  int indent, indent_len, i, j, self_indent;
-  char *indent_char;
-  gboolean first;
-  GString *attr_value = NULL;
-  int len;
-  PyObject *result = NULL;
-
-  if (!PyArg_ParseTuple(args, "sO!isi",
-			&tag_name, &PyList_Type, &attributes,
-			&self_indent, &indent_char,
-			&indent))
-    return NULL;
-
-  if (attributes == Py_None || !PyList_Size(attributes))
-    return PyUnicode_DecodeUTF8("", 0, "strict");
-
-  len = calc_attrs_length(attributes, indent, self_indent);
-  if (len < 0)
-    return NULL;
-  if (len > 79)
-    indent_len = self_indent + strlen(tag_name) + 1;
-  else
-    indent_len = 0;
-
-  first = TRUE;
-  attr_value = g_string_new ("");
-
-  for (i = 0; i < PyList_Size (attributes); ++i)
-    {
-      PyObject *tuple, *pyvalue;
-      PyObject *s = NULL;
-      char *attr, *value, *escaped;
-
-      tuple = PyList_GetItem (attributes, i);
-
-      if (!PyTuple_Check (tuple))
-        {
-          PyErr_SetString(PyExc_TypeError,
-                          "attribute item must be a tuple");
-	  goto out;
-        }
-
-      if (PyTuple_Size (tuple) != 2)
-        {
-          PyErr_SetString(PyExc_IndexError,
-                          "attribute item must be a tuple of length 2");
-	  goto out;
-        }
-
-      if (PyTuple_GetItem(tuple, 1) == Py_None)
-	continue;
-
-      /* this leaks, but we exit after, so */
-      if (!PyArg_ParseTuple(tuple, "sO", &attr, &pyvalue))
-	goto out;
-
-      if (PyUnicode_Check(pyvalue)) {
-        s = PyUnicode_AsUTF8String(pyvalue);
-        if (!s)
-	  goto out;
-        value = PyBytes_AsString(s);
-      } else if (PyBytes_Check(pyvalue)) {
-        value = PyBytes_AsString(pyvalue);
-      } else {
-        PyErr_SetString(PyExc_TypeError,
-                        "value must be string or unicode");
-	goto out;
-      }
-
-      if (indent_len && !first)
-	{
-	  g_string_append_c (attr_value, '\n');
-	  for (j = 0; j < indent_len; j++)
-	    g_string_append_c (attr_value, ' ');
-	}
-      g_string_append_c (attr_value, ' ');
-      g_string_append (attr_value, attr);
-      g_string_append_c (attr_value, '=');
-      g_string_append_c (attr_value, '\"');
-      escaped = g_markup_escape_text (value, -1);
-      g_string_append (attr_value, escaped);
-      g_string_append_c (attr_value, '\"');
-      if (first)
-	first = FALSE;
-      Py_XDECREF(s);
-  }
-
-  result = PyUnicode_DecodeUTF8 (attr_value->str, attr_value->len, "strict");
- out:
-  if (attr_value != NULL)
-    g_string_free (attr_value, TRUE);
-  return result;
-}
-
 /* Module */
 
-static PyMethodDef pyscanner_functions[] = {
-  { "collect_attributes",
-    (PyCFunction) pygi_collect_attributes, METH_VARARGS },
-  { NULL, NULL, 0, NULL }
-};
-
 #if PY_MAJOR_VERSION >= 3
 static struct PyModuleDef moduledef = {
 	PyModuleDef_HEAD_INIT,
 	NULL, /* m_name */
 	NULL, /* m_doc */
 	0,
-	pyscanner_functions,
+	NULL,
 	NULL
 };
 #endif /* PY_MAJOR_VERSION >= 3 */
@@ -851,7 +612,7 @@ MOD_INIT(_giscanner)
     moduledef.m_name = module_name;
     m = PyModule_Create (&moduledef);
 #else
-    m = Py_InitModule (module_name, (PyMethodDef*)pyscanner_functions);
+    m = Py_InitModule (module_name, NULL);
 #endif
     d = PyModule_GetDict (m);
 
